@@ -27,7 +27,7 @@ func newRuntimeConfigFromCLI(c *cli.Context) *util.Config {
 		AnnounceToCLI:     true,
 		Cache:             c.Duration("cache"),
 		Debug:             c.Bool("debug"),
-		LogLevel:          c.GlobalString("loglevel"),
+		LogLevel:          c.GlobalString("log-level"),
 		Endpoint:          c.String("endpoint"),
 		FormatOptions:     c.StringSlice("format-options"),
 		IgnoreList:        c.GlobalStringSlice("exclude-attr"),
@@ -67,7 +67,6 @@ func timeoutFlag(value time.Duration) cli.DurationFlag {
 }
 
 func main() {
-	startTime := time.Now()
 	app := cli.NewApp()
 	app.EnableBashCompletion = true
 	app.Version = version
@@ -75,7 +74,7 @@ func main() {
 	app.Usage = "Quick and Easy server validation"
 	app.Flags = []cli.Flag{
 		cli.StringFlag{
-			Name:   "loglevel, L",
+			Name:   "log-level, loglevel, L, l",
 			Value:  "FATAL",
 			Usage:  "Goss log verbosity level",
 			EnvVar: "GOSS_LOGLEVEL",
@@ -149,7 +148,7 @@ func main() {
 			},
 			Action: func(c *cli.Context) error {
 				fatalAlphaIfNeeded(c)
-				code, err := goss.Validate(newRuntimeConfigFromCLI(c), startTime)
+				code, err := goss.Validate(newRuntimeConfigFromCLI(c))
 				if err != nil {
 					color.Red(fmt.Sprintf("Error: %v\n", err))
 				}
@@ -211,7 +210,7 @@ func main() {
 			Flags: []cli.Flag{
 				cli.BoolFlag{
 					Name:  "debug, d",
-					Usage: fmt.Sprintf("Print debugging info when rendering"),
+					Usage: "Print debugging info when rendering",
 				},
 			},
 			Action: func(c *cli.Context) error {
@@ -416,14 +415,14 @@ func addAlphaFlagIfNeeded(app *cli.App) {
 	if runtime.GOOS == "darwin" || runtime.GOOS == "windows" {
 		app.Flags = append(app.Flags, cli.StringFlag{
 			Name:   "use-alpha",
-			Usage:  fmt.Sprintf("goss is alpha-quality. Set to 1 to use anyway."),
+			Usage:  "goss on macOS/Windows is alpha-quality. Set to 1 to use anyway.",
 			EnvVar: "GOSS_USE_ALPHA",
 			Value:  "0",
 		})
 	}
 }
 
-const msgFormat string = `WARNING: goss for this platform (%q) is alpha-quality, work-in-progress, and not yet exercised within continuous integration.
+const msgFormat string = `WARNING: goss for this platform (%q) is alpha-quality, work-in-progress and community-supported.
 
 You should not expect everything to work. Treat linux as the canonical behaviour to expect.
 
