@@ -17,15 +17,22 @@ type Json struct{}
 func (r Json) ValidOptions() []*formatOption {
 	return []*formatOption{
 		{name: foPretty},
+		{name: foSort},
 	}
 }
 
 func (r Json) Output(w io.Writer, results <-chan []resource.TestResult,
-	startTime time.Time, outConfig util.OutputConfig) (exitCode int) {
+	outConfig util.OutputConfig) (exitCode int) {
 
 	var pretty bool
 	pretty = util.IsValueInList(foPretty, outConfig.FormatOptions)
+	includeRaw := !util.IsValueInList(foExcludeRaw, outConfig.FormatOptions)
 
+	sort := util.IsValueInList(foSort, outConfig.FormatOptions)
+	results = getResults(results, sort)
+
+	var startTime time.Time
+	var endTime time.Time
 	color.NoColor = true
 	testCount := 0
 	failed := 0
@@ -33,7 +40,13 @@ func (r Json) Output(w io.Writer, results <-chan []resource.TestResult,
 	var resultsOut []map[string]any
 	for resultGroup := range results {
 		for _, testResult := range resultGroup {
-			if !testResult.Successful {
+			if startTime.IsZero() || testResult.StartTime.Before(startTime) {
+				startTime = testResult.StartTime
+			}
+			if endTime.IsZero() || testResult.EndTime.After(endTime) {
+				endTime = testResult.EndTime
+			}
+			if testResult.Result == resource.FAIL {
 				failed++
 				logTrace("WARN", "FAIL", testResult, true)
 			} else {
@@ -43,7 +56,9 @@ func (r Json) Output(w io.Writer, results <-chan []resource.TestResult,
 				skipped++
 			}
 			m := struct2map(testResult)
-			m["summary-line"] = humanizeResult(testResult)
+			m["successful"] = testResult.Result != resource.FAIL
+			m["summary-line"] = humanizeResult(testResult, false, includeRaw)
+			m["summary-line-compact"] = humanizeResult(testResult, true, includeRaw)
 			m["duration"] = int64(m["duration"].(float64))
 			resultsOut = append(resultsOut, m)
 			testCount++
@@ -51,7 +66,7 @@ func (r Json) Output(w io.Writer, results <-chan []resource.TestResult,
 	}
 
 	summary := make(map[string]any)
-	duration := time.Since(startTime)
+	duration := endTime.Sub(startTime)
 	summary["test-count"] = testCount
 	summary["failed-count"] = failed
 	summary["skipped-count"] = skipped
